

# Example slide with equations

We can use inline equations, `\(E = mc^2\)`, or full-line equations like:

`$$ \Gamma(t) = \pi \, \Im\left\{ \mathbf{x}_+^H(t) \, \frac{\mathrm{d}}{\mathrm{d} t}\mathbf{x}_+(t) \right\} $$`

You can just write in LaTeX, with minor modifications for specifying in-line or
full-line equations.

See [MathJax](https://www.mathjax.org) for more details and examples.
